==> rest-connect-1.12.23-sources.jar: org/mule/connectivity/restconnect/internal/modelGeneration/ramlParser/resourceLoader/SafeProxyResourceLoader.java <==
package org.mule.connectivity.restconnect.internal.modelGeneration.ramlParser.resourceLoader;

import static java.lang.String.format;
import static org.mule.connectivity.restconnect.internal.modelGeneration.util.ResourceLoaderUtils.getHttpURLConnection;
import static org.slf4j.LoggerFactory.getLogger;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;

import javax.annotation.Nullable;

import org.raml.v2.api.loader.ResourceLoaderExtended;
import org.raml.v2.api.loader.ResourceUriCallback;
import org.slf4j.Logger;

public class SafeProxyResourceLoader implements ResourceLoaderExtended {

    private static final Logger LOGGER = getLogger(SafeProxyResourceLoader.class);

    private final String proxyUri;
    private final String proxyReferer;

    public SafeProxyResourceLoader(String proxyUri, String proxyReferer){
        this.proxyUri = proxyUri;
        this.proxyReferer = proxyReferer;
    }

    private URI callbackParam;

    @Override
    public InputStream fetchResource(String resourceName, ResourceUriCallback callback)
    {
        InputStream inputStream = null;
        try
        {
            URL url = new URL(format("%s/%s", proxyUri, resourceName));
            HttpURLConnection connection = getHttpURLConnection(url, proxyReferer);

            if(connection.getResponseCode() != 200){
                return null;
            }

            inputStream = new BufferedInputStream(connection.getInputStream());

            if (callback != null)
            {
                callbackParam = url.toURI();
                callback.onResourceFound(url.toURI());
            }
        }
        catch (IOException | URISyntaxException e)
        {
            LOGGER.warn("Error fetching resource", e);
        }

        return inputStream;
    }

    @Nullable
    @Override
    public InputStream fetchResource(String resourceName)
    {
        return fetchResource(resourceName, null);
    }

    @Override
    public URI getUriCallBackParam()
    {
        return callbackParam;
    }
}

==> rest-connect-1.12.24-sources.jar: org/mule/connectivity/restconnect/internal/modelGeneration/ramlParser/resourceLoader/SafeProxyResourceLoader.java <==
package org.mule.connectivity.restconnect.internal.modelGeneration.ramlParser.resourceLoader;

import static java.lang.String.format;
import static org.mule.connectivity.restconnect.internal.modelGeneration.util.ResourceLoaderUtils.getHttpURLConnection;
import static org.slf4j.LoggerFactory.getLogger;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;

import javax.annotation.Nullable;

import org.raml.v2.api.loader.ResourceLoaderExtended;
import org.raml.v2.api.loader.ResourceUriCallback;
import org.slf4j.Logger;

public class SafeProxyResourceLoader implements ResourceLoaderExtended {

    private static final Logger LOGGER = getLogger(SafeProxyResourceLoader.class);

    private final String proxyUri;
    private final String proxyReferer;
    private final String token;
    private final String orgId;

    public SafeProxyResourceLoader(String proxyUri, String proxyReferer, String token, String orgId){
        this.proxyUri = proxyUri;
        this.proxyReferer = proxyReferer;
        this.token = token;
        this.orgId = orgId;
    }

    private URI callbackParam;

    @Override
    public InputStream fetchResource(String resourceName, ResourceUriCallback callback)
    {
        InputStream inputStream = null;
        try
        {
            URL url = new URL(format("%s/%s", proxyUri, resourceName));
            HttpURLConnection connection = getHttpURLConnection(url, proxyReferer, token, orgId);

            if(connection.getResponseCode() != 200){
                return null;
            }

            inputStream = new BufferedInputStream(connection.getInputStream());

            if (callback != null)
            {
                callbackParam = url.toURI();
                callback.onResourceFound(url.toURI());
            }
        }
        catch (IOException | URISyntaxException e)
        {
            LOGGER.warn("Error fetching resource", e);
        }

        return inputStream;
    }

    @Nullable
    @Override
    public InputStream fetchResource(String resourceName)
    {
        return fetchResource(resourceName, null);
    }

    @Override
    public URI getUriCallBackParam()
    {
        return callbackParam;
    }
}
